@@ -167,7 +167,7 @@ def vertical_distance(left, current, right):
         result = 0
     elif (c_x - a_x) == 0:
         # Otherwise we could have a ZeroDivisionError
-        result = INFINITY
+        result = INFINITY * -1
     else:
         result = abs(((a_y + (c_y - a_y) * (b_x - a_x) / (c_x - a_x) - b_y)) * (c_x - a_x))
 
